==> hugo_0.70.0.orig.tar.gz: hugo-0.70.0/docs/content/en/showcase/arolla-cocoon/index.md <==
---

title: Cocoon & Cosy
date: 2018-08-10
description: "Showcase: \"Emergency setup a dedicated site in an afternoon.\""
siteURL: https://www.cocoon-arolla.com
byline: "[Didier Divinerites](https://github.com/divinerites)"

---

Swiss [Arolla campsite](https://www.camping-arolla.com) runs the highest campsite in Europe and I'm completely re-doing their actuel Website with Hugo.

But they just launch a brand new offer (luxury tents with bed and fire oven), and we couldn't wait for the proper new website for having this promoted: we needed the website up and running within 24h!

So we decided to quickly launch a dedicated [independent web site](https://www.cocoon-arolla.com) using all the powerful tools included with [gohugo.io](https://gohugo.io) and some things we already knew & used:

- Choose a spectacular landing theme in the rich [Hugo Themes](https://themes.gohugo.io/) collection : [Airspace Theme](https://themes.gohugo.io/airspace-hugo/) by Themefisher.
- Replace the main images.
- Add a [hugo-easy-gallery / photoswipe](https://github.com/liwenyip/hugo-easy-gallery) on the main page with attractive images.
- Add the promo video with a simple *vimeo* shortcode.
- Replace the Google Maps widget by the [OpenStreetMap](https://www.openstreetmap.org/) equivalent
- Use a [Zotabox](https://www.zotabox.com) contact form.
- Write the content in French & in English directly on the content pages, describe their services, add fun facts and true testimonies.
- Setup a GDPR compliant site with the new Hugo options.
- Use [Netlify](https://www.netlify.com) for publishing it in a breeze.

The first version was up in 4 hours, and the polished 2 languages version was published on Netlify the next day.

This would have been impossible to do it in such a short time without all the powerful Hugo tools and Netlify simplicity.

==> hugo_0.80.0.orig.tar.gz: hugo-0.80.0/docs/content/en/showcase/arolla-cocoon/index.md <==
---

title: Cocoon & Cosy
date: 2018-08-10
description: "Showcase: \"Emergency setup a dedicated site in an afternoon.\""
siteURL: https://www.cocoon-arolla.com
byline: "[Didier Divinerites](https://github.com/divinerites)"

---

Swiss [Arolla campsite](https://www.camping-arolla.com) runs the highest campsite in Europe and I'm completely re-doing their actual Website with Hugo.

But they just launch a brand new offer (luxury tents with bed and fire oven), and we couldn't wait for the proper new website for having this promoted: we needed the website up and running within 24h!

So we decided to quickly launch a dedicated [independent web site](https://www.cocoon-arolla.com) using all the powerful tools included with [gohugo.io](https://gohugo.io) and some things we already knew & used:

- Choose a spectacular landing theme in the rich [Hugo Themes](https://themes.gohugo.io/) collection : [Airspace Theme](https://themes.gohugo.io/airspace-hugo/) by Themefisher.
- Replace the main images.
- Add a [hugo-easy-gallery / photoswipe](https://github.com/liwenyip/hugo-easy-gallery) on the main page with attractive images.
- Add the promo video with a simple *vimeo* shortcode.
- Replace the Google Maps widget by the [OpenStreetMap](https://www.openstreetmap.org/) equivalent
- Use a [Zotabox](https://www.zotabox.com) contact form.
- Write the content in French & in English directly on the content pages, describe their services, add fun facts and true testimonies.
- Setup a GDPR compliant site with the new Hugo options.
- Use [Netlify](https://www.netlify.com) for publishing it in a breeze.

The first version was up in 4 hours, and the polished 2 languages version was published on Netlify the next day.

This would have been impossible to do it in such a short time without all the powerful Hugo tools and Netlify simplicity.
